codons2bases <-
structure(function(nc=16, print.data=TRUE, only.summary=TRUE){
	# codons2bases; SEE "# Here, new version of codons2bases" in 6_ProgCodonInfo.txt
	# This version could have two outputs:
	# res (which is a summary in tabular form) and
	#  
	# nc = Number of column of the matrix "codon.freq"
	# Must be in environment: "codon.freq", "code
	col.name <- attributes(codon.freq)$dimnames[[2]][nc]
	temp.fr <- codon.freq[,nc] # Frequencies of codons
	# Check triplets
	if(prod(attributes(temp.fr)$names == gen.code$codon) != 1) stop("The frequencies are not valid.")
	stop.present <- TRUE
	if(sum(temp.fr[62:64]) == 0) stop.present <- FALSE
	if(print.data == TRUE){
		# Print basic info:
		cat("\nData for column: ", nc, "\nBasic information:\n", sep="")
		print(desc.codon.freq[nc, 1:5])
		temp.cod <- prettyNum(sum(temp.fr), big.mark = ",")
		temp.bas <- prettyNum(3*sum(temp.fr), big.mark = ",")
		cat("Total of codons: ", temp.cod, "; Total of bases: ", temp.bas, "\n", sep="")
		if(stop.present == TRUE){
			cat("Stop codons are present in the data.\n")
		} else {
			cat("Stop codons are NOT present in the data.\n")
		}
		
	}
	temp.bases <- c("A", "T", "G", "C")
	res <- matrix(NA, nrow=4, ncol=4, dimnames=list(c("F", "S", "T", "Total"), temp.bases))
	for(i in 1:4){
		res[1, i] <- sum(temp.fr[c(1:64)[gen.code$fb==temp.bases[i]]])
		res[2, i] <- sum(temp.fr[c(1:64)[gen.code$sb==temp.bases[i]]])
		res[3, i] <- sum(temp.fr[c(1:64)[gen.code$tb==temp.bases[i]]]) 
	}
	res[4, 1:4] <- apply(res[1:3,], 2, sum)
	comment(res) <- col.name
	# Decide the output:
	if(only.summary == TRUE){
		return(res)
	} else {
		# Calculate the f.c.b
		f.c.b <- gen.code
		f.c.b$freq.cod <- temp.fr
		# Make all 3x4=12 variables:
		f.c.b$fb.A <- 0 + f.c.b$freq.cod*(f.c.b$fb=="A")
		f.c.b$fb.T <- 0 + f.c.b$freq.cod*(f.c.b$fb=="T")
		f.c.b$fb.G <- 0 + f.c.b$freq.cod*(f.c.b$fb=="G")
		f.c.b$fb.C <- 0 + f.c.b$freq.cod*(f.c.b$fb=="C")
		f.c.b$sb.A <- 0 + f.c.b$freq.cod*(f.c.b$sb=="A")
		f.c.b$sb.T <- 0 + f.c.b$freq.cod*(f.c.b$sb=="T")
		f.c.b$sb.G <- 0 + f.c.b$freq.cod*(f.c.b$sb=="G")
		f.c.b$sb.C <- 0 + f.c.b$freq.cod*(f.c.b$sb=="C")
		f.c.b$tb.A <- 0 + f.c.b$freq.cod*(f.c.b$tb=="A")
		f.c.b$tb.T <- 0 + f.c.b$freq.cod*(f.c.b$tb=="T")
		f.c.b$tb.G <- 0 + f.c.b$freq.cod*(f.c.b$tb=="G")
		f.c.b$tb.C <- 0 + f.c.b$freq.cod*(f.c.b$tb=="C")	
		comment(f.c.b) <- col.name
	}
	end.res <- list(res, f.c.b)
	names(end.res) <- c("summ.tab", "f.c.b")
	end.res
}, comment = c("Parameters: nc - Number of Column; print.data (logic); only.summary (logic)", 
"Output: If only.summary=T, a matrix with a summary of frequencies; otherwise also a data.frame named f.c.b with details per codon."
))
