est.H <-
structure(function(x=c(3/4, 1/4), tol.in.sum=1e-10){
	# est.H
	# Estimates entropy (H) and related properties for a vactor x of relative frequencies.
	# tol.in.sum - Tolerance to be given in sum
	if(1-sum(x) > tol.in.sum) stop("x must be a vector of relative frequencies! (it does not add to 1)")
	x <- x[x>0]
	n <- length(x)
	H <- -sum(x*log2(x))
	# Note that the maximum value of H is log2(n)
	# Now, the parameter "EN" stands for "Effective Number" 
	res <- c(n, H, 2^H, log2(n)-H, var(x))
	names(res) <- c("n", "Hest", "EN", "Info", "V.est")
	res
}, comment = "Estimates information properties from a vector of relative frequencies, x. Output: n - length of the vector x; Hest - Estimated value of the entropy, H; EN - Effective Number, i.e., 2^Hest; Info - log2(n) - Hest = H_max - Hest.")
