prop.codons <-
structure(function(nc=16){
	# Will calculate statistics and properties at codon level.
	# nc - Number of Column where the original data are stored.
	# nc=16 is Human (default)
	# Get lib.name
	lib.name <- attributes(codon.freq)$dimnames[[2]][nc]

	fre.c <- codon.freq[,nc] # (frequencies of codons)
	tot.cod <- sum(fre.c)
	
	r.fre.c <- fre.c/tot.cod
	# est.H input relative frequencies and gives c("n", "Hest", "EN", "Info", "V.est")
	# Will use only Hest [2] as H.1 (directly estimated from relative frequencies)
	temp.H.1 <- est.H(r.fre.c)[2:5]
	names(temp.H.1)[2] <- "ENC" # Effective number of codons
#	names(H.1) <- "H.1"
#	I.1 <- 6 - H.1 # Maximum posible entropy minus entropy estimated from relative frequencies
#	names(I.1) <- "I.1"
	fre.b <- prop.bases(nc=nc) # Frequencies of bases.
	data.name <- comment(fre.b)
	fre.bases <- unlist(fre.b[4,1:4]) # Order "A", "T", "G", "C"

	# Now we can calculate the Expected values for the frequencies of codons
	exp.cod.2 <- rep(NA, 64) # Initialize the expected values using total of bases!
	for(i in 1:64){ # For each une of the 64 values
		temp <- NA
		# First base
		if(gen.code$fb[i]=="A") {temp <- fre.bases[1]}
		if(gen.code$fb[i]=="T") {temp <- fre.bases[2]}
		if(gen.code$fb[i]=="G") {temp <- fre.bases[3]}
		if(gen.code$fb[i]=="C") {temp <- fre.bases[4]}
		# second base
		if(gen.code$sb[i]=="A") {temp <- temp*fre.bases[1]}
		if(gen.code$sb[i]=="T") {temp <- temp*fre.bases[2]}
		if(gen.code$sb[i]=="G") {temp <- temp*fre.bases[3]}
		if(gen.code$sb[i]=="C") {temp <- temp*fre.bases[4]}
		# third base
		if(gen.code$tb[i]=="A") {temp <- temp*fre.bases[1]}
		if(gen.code$tb[i]=="T") {temp <- temp*fre.bases[2]}
		if(gen.code$tb[i]=="G") {temp <- temp*fre.bases[3]}
		if(gen.code$tb[i]=="C") {temp <- temp*fre.bases[4]}
		exp.cod.2[i] <- temp
	}
	# Will use only Hest [2:5] as H.2 (estimated from expected of codons given base frequencie)
	temp.H.2 <- est.H(exp.cod.2)[2:5]
	names(temp.H.2)[2] <- "ENC"

	# Constructing results of frequencies (deprecated)	
	# Calculating with the frequencies of bases within each codon.
	fre.b1 <- unlist(fre.b[1,1:4]) # Order "A", "T", "G", "C"
	fre.b2 <- unlist(fre.b[2,1:4]) # Order "A", "T", "G", "C"
	fre.b3 <- unlist(fre.b[3,1:4]) # Order "A", "T", "G", "C"

	exp.cod.3 <- rep(NA, 64) # Initialize the expected values using total of bases!
	for(i in 1:64){ # For each une of the 64 values
		temp <- NA
		# First base
		if(gen.code$fb[i]=="A") {temp <- fre.b1[1]}
		if(gen.code$fb[i]=="T") {temp <- fre.b1[2]}
		if(gen.code$fb[i]=="G") {temp <- fre.b1[3]}
		if(gen.code$fb[i]=="C") {temp <- fre.b1[4]}
		# second base
		if(gen.code$sb[i]=="A") {temp <- temp*fre.b2[1]}
		if(gen.code$sb[i]=="T") {temp <- temp*fre.b2[2]}
		if(gen.code$sb[i]=="G") {temp <- temp*fre.b2[3]}
		if(gen.code$sb[i]=="C") {temp <- temp*fre.b2[4]}
		# third base
		if(gen.code$tb[i]=="A") {temp <- temp*fre.b3[1]}
		if(gen.code$tb[i]=="T") {temp <- temp*fre.b3[2]}
		if(gen.code$tb[i]=="G") {temp <- temp*fre.b3[3]}
		if(gen.code$tb[i]=="C") {temp <- temp*fre.b3[4]}
		exp.cod.3[i] <- temp
	}

	# Constructing results of frequencies
# OLD: res.fre <- data.frame(data=data.name, codon=gen.code$codon, aa=gen.code$aa, fre.obs=fre.c, fre.E.tb=tot.cod*exp.cod.2, fre.E.cb=tot.cod*exp.cod.3)
	res.fre <- data.frame(codon=gen.code$codon, aa=gen.code$aa, ObsFreq=fre.c, ExpBase=tot.cod*exp.cod.2, ExpBinC=tot.cod*exp.cod.3)
	
	# Will use only Hest [2] as H.2 (estimated from expected of codons given bases per position)
	temp.H.3 <- est.H(exp.cod.3)[2:5]
	names(temp.H.3)[2] <- "ENC"
	
	H.est <- matrix(c(temp.H.1, temp.H.2, temp.H.3), nrow=3, ncol=4, byrow=TRUE, dimnames=list(c("ObsFreq", "ExpBase", "ExpBinC"), names(temp.H.1)))

	res <- list(H.est, res.fre)
	names(res) <- c("H.est", "frequencies")
	comment(res) <- lib.name
	res
}, comment = c("Input: nc (Number of Column of codon.freq)", 
"Output: a list with two components, the first H.est, a 3 rows by 4 columns matrix with informational properties for three frequencies and the second, frequencies, a data.frame with 64 rows (one for each codon) with information for three frequencies."
))
