\name{CodonInfo-package}
\alias{CodonInfo-package}
\alias{CodonInfo}
\docType{package}
\title{
\packageTitle{CodonInfo}
}
\description{
\packageDescription{CodonInfo}
}
\details{

The DESCRIPTION file:
\packageDESCRIPTION{CodonInfo}
\packageIndices{CodonInfo}
}
\author{
\packageAuthor{CodonInfo}

Maintainer: \packageMaintainer{CodonInfo}
}
\references{
Shannon, C.E. 1948. A mathematical theory of communication. Bell Systems Technical Journal 27:379-423; ibid 27:623-656; reprinted in C.E. Shannon: Collected Papers, N.J.A. Sloane and A.D. Wyner, eds., IEEE Press (1993).

Adami C. (2004). Information Theory in Molecular Biology. Physics of Life Reviews, Volume 1, Issue 1, April 2004, Pages 3-22.

Martinez O and Reyes-Valdes H. (2008). Defining diversity, specialization, and gene specificity in transcriptomes through information theory. PNAS, 105:28, pp. 9709–9714.

Subramanian K, Payne B, Feyertag F, and Alvarez-Ponce D (2022) The codon statistics database: a database of codon usage bias. Molecular Biology and Evolution, 39, msac157.

Martinez O. (In preparation). Sampling informational properties of codon use through the tree of life.
}
\keyword{ package }
\examples{
# Estimate entropy and related quantities
# in a vector of 4 relative frequencies:
est.H(c(0.2, 0.2, 0.3, 0.3))

# Estimate frequencies of bases and informational properties
# for the human frequencies of codons
round(prop.bases(nc=16, print.data=TRUE), 4)

# Estimate frequencies of bases and informational properties
# for Entamoeba histolytica
round(prop.bases(nc=10, print.data=TRUE), 4)

# Use function "prop.codons" to estimate properties at
# codon level in humans (nc=16)
temp <- prop.codons(16)
# See that this object is a list with two components:
class(temp)
# Note that the comment of this object contains the name
# of the library:
comment(temp)
# Names of the components:
names(temp)
# Summary of informational properties at codon level:
temp$H.est
# Head of the second component
head(temp$frequencies)
# Correlations between observed and expected frequencies
cor(temp$frequencies[,3:5])
# Remove the temp object
rm(temp)

# Studying codon.bias information in humans
temp <- codon.bias(nc=16)
# Gives a data.frame with results for the 19
# amino acids (aa) which can present codon bias
# (because they are coded by more than one codon)
dim(temp)
names(temp)
# Summary of main quantities
summary(temp[,4:7])
# Amino acid with smaller codon bias in humans:
temp[temp$CodBias.aa==min(temp$CodBias.aa),]
# Amino acid with larger codon bias in humans:
temp[temp$CodBias.aa==max(temp$CodBias.aa),]
# Example: aa with smaller codon bias
head(temp[order(temp$CodBias.aa), 3:7])
# Example: aa with larger codon bias
tail(temp[order(temp$CodBias.aa), 3:7])
# Remove temp object
rm(temp)
}
