\name{codon.bias}
\alias{codon.bias}
\title{
Informational properties for amino acids coded by more than one codon
}
\description{
For each one of the 19 amino acids (\code{aa}) coded by more than one codon, the function estimates informational properties, including codon bias
}
\usage{
codon.bias(nc = 16, only.main = FALSE)
}
\arguments{
  \item{nc}{
Number of column of the matrix \code{codon.freq} (currently values of this parameter could be numbers 1 to 35, which determine the species to be analyzed)
}
  \item{only.main}{
\code{logical}. If \code{only.main = FALSE} only main results are obtained. Otherwise extra parameters are estimated
}
}
\details{
The function calculates informational properties for all 19 cases where amino acid (\code{aa}) is coded by 2 or more codons. This includes the case of \code{Stop} (coded by codons \code{TAA, TAG, TGA}) but excludes the amino acids coded by a single codon, i.e., \code{Met} and \code{Trp} which are coded by codons \code{ATG} and \code{TGG}, respectively
}
\value{
If \code{only.main = FALSE} (the default) a \code{data.frame} with 19 rows (amino acids, \code{aa}) and 12 columns named \code{libray} (name of the data library), 
\code{fre.aa} (frequency of the amino acid), \code{aa} (amino acid three letter code), 
\code{n.cod} (number of codons coding for the \code{aa}), \code{H.per.aa} (Entropy for the \code{aa}, calculated from the frequencies of the codons that code for that \code{aa}), \code{H.all} (Entropy for the \code{aa}, calculated from the frequencies of the bases that exist in the codons that code for that \code{aa}), \code{Hfb} (Entropy calculated using only the first base of the codons that code for that \code{aa}), \code{Hsb} (Entropy calculated using only the second base of the codons that code for that \code{aa}), \code{Htb} (Entropy calculated using only the third base of the codons that code for that \code{aa}), \code{H.max.aa} (maximum value of entropy determined by \code{n.cod}), \code{ENC} (Effective Number of Codons) and    
\code{CodBias.aa} (Codon Bias for the \code{aa}; a quantity that can take values from 0 -when all codons are used exactly in the same frequency, up to 1 -when only one of the codons is employed by the specie). If \code{only.main = TRUE} then only columns \code{aa}, \code{n.cod}, \code{H.per.aa}, \code{ENC} and \code{CodBias.aa} will be in the output
}
\references{
Martinez O. (In preparation). Sampling informational properties of codon use through the tree of life.
}
\author{
Octavio Martinez
}
\seealso{
\code{\link{codon.freq}}, \code{\link{desc.codon.freq}}, \code{\link{codons2bases}}, \code{\link{prop.bases}}, \code{\link{prop.codons}}
}
\examples{
# Let's calculate codon bias for the case of humans:
temp <- codon.bias(nc = 16, only.main = FALSE)
dim(temp) # Number of rows and columns
# See the first row of the result
temp[1,]
# Recall which codons code for "Ala"
gen.code.n.cod[gen.code.n.cod$aa=="Ala",]
# Note that the first and second bases of those 4 codons are
# the same: "GC", thus the values of Hfb and Hsb are equal to 0.
# The entropy caused by the third base (A, C, G, T) is Htb=1.872992
# while the entropy caused by taking into account the frequencies 
# of the four bases is H.all=1.635944
# By isolating the frequencies of the 4 codons in the data 
# we obtained H.per.aa=1.872992 and, finally, the Codon Bias for
# Ala is obtained as (2-ENB)/(2-1), that is
(4-3.662915)/(4-1) # Approximately 0.1123617

# We could see the summary of CodBias.aa
summary(temp$CodBias.aa)
# Which is the aa with smaller Codon bias?
temp[temp$CodBias.aa == min(temp$CodBias.aa),]
# And the one with the larger Codon bias?
temp[temp$CodBias.aa == max(temp$CodBias.aa),]
# Remove the temp object
rm(temp)
}