\name{codon.freq}
\alias{codon.freq}
\docType{data}
\title{
Raw frequencies of codons in genes of 35 species
}
\description{
A numeric \code{matrix} of 64 rows (codons) and 35 columns (species) containing the raw frequencies of codons found in each one of the species. These data are the base for all calculations that could be performed in the package. In many functions to select the species that will be analyzed the only data needed is the number of column of this matrix, say, \code{nc}, which must be a number between 1 and 35. It is possible to add any number of data (columns) to this matrix to perform analyzes in species not already included.
}
\usage{data("codon.freq")}
\format{
Numeric matrix with the raw frequencies of codons (64 rows) in different species (35 columns). \code{attributes(codon.freq)$dimnames[[1]]} are the codons, \code{GCT}, \code{GCC}, etc., while \code{attributes(codon.freq)$dimnames[[2]]} are the library names, \code{A.d.70779}, \code{A.a.5599}, etc. Those library names are formed by the first letter of the genus, the first letter of the species and the number which is the identifier of the taxa (in NCBI).
}
\details{
Not missing data (\code{NA}) are present or allowed. In the cases where the Stop codons were not present (as in the case of the library   \code{nc=11}; Enterovirus C; E.C.138950) the number of each possible stop codon was set to 1.
}
\source{
	\href{http://codonstatsdb.unr.edu/}{Codon Statistics Database}
}
\references{
Subramanian K, Payne B, Feyertag F, and Alvarez-Ponce D (2022) The codon statistics database: a database of codon usage bias. Molecular Biology and Evolution, 39, msac157.
}
\examples{
data(codon.freq)
data(codon.freq)
# Rows and columns:
dim(codon.freq)
# Summary of sum of raw frequencies (all codons in all libraries)
summary(as.numeric(codon.freq))
# Summary of sum of raw frequencies per codon
summary(apply(codon.freq, 1, sum))
# Summary of sum of raw frequencies per library (species)
summary(apply(codon.freq, 2, sum))
# Some correlations between row frequencies
round(cor(codon.freq[,1:5]),2)
# A particularly large one
cor(codon.freq[,4], codon.freq[,5])
codon.freq[1:5, 4:5]
# Which are those species?
desc.codon.freq[4:5,]
}
\keyword{datasets}
