\name{codons2bases}
\alias{codons2bases}
\title{
Frequencies of bases in a species
}
\description{
Gives raw frequencies of each one of the four DNA bases (A, T, G, C) for a determined species. Optionally gives general information about the specie as well as a \code{data.frame} with detailed information about the frequencies of each base within each codon
}
\usage{
codons2bases(nc = 16, print.data = TRUE, only.summary = TRUE)
}
\arguments{
  \item{nc}{
Number of column of the matrix \code{codon.freq} (currently values of this parameter could be numbers 1 to 35, which determine the species to be analyzed)
}
  \item{print.data}{
Logic. Determines if the information about the species will be printed
}
  \item{only.summary}{
Logic. Determines if only the summary table will be output (when \code{only.summary=TRUE}) or if also a \code{data.frame} with details of the frequencies per codon and position within codon will be output (when \code{only.summary=FALSE})
}
}
\details{
The function segregates the frequencies of each DNA base by position within codons
}
\value{
If \code{print.data = TRUE} and \code{only.summary = TRUE} then the function prints information about the data been analyzed and the output consist of a \code{matrix} of 4 rows and 4 columns. Columns of that matrix are labeled by the DNA bases (A, T, G, C) while the rows are labeled as F, S, T and Total, denoting the frequencies in the First, Second, Third and Total of each base in the codons of the species studied, respectively. 

Else, if \code{print.data = FALSE} and \code{only.summary = TRUE} then the information about the species is not printed but the result is as described above.

Else, if \code{print.data = TRUE} and \code{only.summary = FALSE} then information about the species is printed but the result is a \code{list} of two components:
  \item{summ.tab }{The \code{matrix} of frequencies described above}
  \item{f.c.b }{A \code{data.frame} of 64 rows and 18 columns giving frequencies for each one of the codons and columns segregating by the position of the base within each codon}

Finally, if \code{print.data = FALSE} and \code{only.summary = FALSE} then no information about the specie is printed and the result is a \code{list} of two components, as described above
}
\references{
Martinez O. (In preparation). Sampling informational properties of codon use through the tree of life.
}
\author{
Octavio Martinez
}
\note{
This function is not directly useful for the user, but is employed by other functions in the package
}
\seealso{
\code{\link{codon.freq}}, \code{\link{desc.codon.freq}}, \code{\link{prop.bases}}, \code{\link{prop.codons}}, \code{\link{codon.bias}}
}
\examples{
# First, with the defaults for the function, i.e., with
# { codons2bases(nc = 16, print.data = TRUE, only.summary = TRUE) }
codons2bases()
# The function printed the information about nc=16 (data for humans)
# and the matrix in the output shows raw frequencies per base (column)
# and position within the codon. Thus for example there are 
# 3086621 A's in the first position of the codons, 1985713 T's and so on.
# The last row of this matrix gives the number of bases (A, T, G, C) in
# all the three codons positions, for example there is a total of 
# 8965555 A's in the genome; 3086621 in the first, 3597976 in the second 
# and 2280958 in the third codon position, thus:
# 3086621 + 3597976 + 2280958 = 8965555 give the total A's in the genome.

# Now, let's try the options print.data=FALSE and only.summary=FALSE
temp <- codons2bases(nc=16, print.data=F, only.summary=F)
class(temp) # In this case we have a list with names
names(temp)
temp[[1]] # As the matrix above
# Now let's examine the second component
class(temp[[2]])
dim(temp[[2]])
names(temp[[2]])
temp[[2]][1,] # See the first row of the data.frame
# Note that adding by columns we get the same info than in temp[[1]]
# only with more details
apply(temp[[2]][, 6:18], 2, sum)
# Note about the names: fb means first base (within codon), sb means
# second base (within codon) and tb means third base (within codon)
# and compare with 
temp[[1]]
# Remove the temp object
rm(temp)
}