\name{desc.codon.freq}
\alias{desc.codon.freq}
\docType{data}
\title{
Description of the data in \code{codon.freq}
}
\description{
This \code{data.frame} depicts the main characteristics of each one of the 35 columns that contain raw frequencies for the 64 codons in the matrix of data \code{codon.freq}. This information allows the interpretation of the results of the functions in the package that analyze those raw frequencies
}
\usage{data("desc.codon.freq")}
\format{
  A data frame with 35 observations on the following 12 variables.
  \describe{
    \item{\code{Kingdom}}{a character vector with the taxonomic kingdom for the species}
    \item{\code{Species}}{a character vector with the scientific name of the species}
    \item{\code{common.name}}{a character vector containing the common name of the species}
    \item{\code{tax.id}}{a numeric vector with the taxonomic identifier of the species (NCBI)}
    \item{\code{key}}{a character vector with the first two letters of each word in \code{Species} pasted with a full stop}
    \item{\code{object}}{a character vector with the name of the object originally downloaded from the source; scientific name plus taxonomic id pasted with full stops}
    \item{\code{cod.tab}}{a numeric vector with the identifier of the genetic code for the data}
    \item{\code{tot.nuc.gen}}{a numeric vector with the total number of genes for the species studied}
    \item{\code{tot.cod}}{a numeric vector with the total number of codons in the genes for the species studied}
    \item{\code{run.dat}}{a character vector with the date (year-month-day) when the data were collected}
    \item{\code{lib.name}}{a character vector with the library name of the data. This unique identifier is formed by the \code{key} pasted with the \code{tax.id} by a full stop. It is identical to the column names of the data matrix \code{codon.freq}}
    \item{\code{col.in.codon.freq}}{a numeric vector with the number of column in the data matrix \code{codon.freq}}
  }
}
\source{
\href{http://codonstatsdb.unr.edu/}{Codon Statistics Database}
}
\references{
Subramanian K, Payne B, Feyertag F, and Alvarez-Ponce D (2022) The codon statistics database: a database of codon usage bias. Molecular Biology and Evolution, 39, msac157.
}
\examples{
data(desc.codon.freq)
# Examples of the unique identifiers for the data
head(desc.codon.freq[,c(2,4,5,11)])
# Note that desc.codon.freq$lib.name is identical to the names
# of the columns of code.freq
head(desc.codon.freq$lib.name)
# Identical to
head(attributes(codon.freq)$dimnames[[2]])

# There are 7 Kingdoms represented in this data
unique(desc.codon.freq$Kingdom)
# And here we have the table with the number of species per kingdom
table(desc.codon.freq$Kingdom)

# Some statistics for the tot.nuc.gen and tot.cod
summary(desc.codon.freq$tot.nuc.gen)
summary(desc.codon.freq$tot.cod)
cor(desc.codon.freq$tot.nuc.gen, desc.codon.freq$tot.cod)
}
\keyword{datasets}
