\name{est.H}
\alias{est.H}
\title{
Estimates informational properties from a vector of relative frequencies
}
\description{
From a \code{numeric} vector of relative frequencies gives a vector with \code{n} - The length of the input vector, \code{Hest} - The entropy (H) estimated from the frequencies, \code{EN} - The Effective Number of units,  \code{Info} - The information content with reference to the maximum entropy and \code{V.est} - The estimated variance of the input vector.
}
\usage{
est.H(x = c(3/4, 1/4), tol.in.sum = 1e-10)
}
\arguments{
  \item{x}{
Must be a numeric vector of relative frequencies adding to 1. No missing values are allowed
}
  \item{tol.in.sum}{
Tolerance for the sum of \code{x}
}
}
\details{
Only \code{x} elements larger than zero are taken into account
}
\value{
	A numeric vector with elements named as \code{n <- length(x)} (number of relative frequencies larger than zero), \code{Hest <- -sum(x*log2(x))} (estimated entropy in bits), \code{EN <- 2^Hest} (Effective Number of units), \code{Info <- log2(n)-Hest} (Information with reference to the maximum entropy), \code{V.est <- var(x)} (Variance of the relative frequencies in the input \code{x})
}
\references{
Martinez O. (In preparation). Sampling informational properties of codon use through the tree of life.
}
\author{
Octavio Martinez
}
\note{
This function is used to calculate informational parameters within other functions in the package
}
\examples{
# Use est.H to estimate informational parameters from the
# relative frequencies of the four bases in the human coding genome.
# First, see those frequencies (using another function)
prop.bases(nc=16)[4, 1:4]
# and now use est.H on than vector:
est.H(prop.bases(nc=16)[4, 1:4]) 
}
