\name{gen.code}
\alias{gen.code}
\docType{data}
\title{
The genetic code
}
\description{
This \code{data.frame} contains the (nuclear) genetic code used to classify the codons into amino acids (\code{aa}). Note that the three stop codons are considered to code for an amino acid
}
\usage{data("gen.code")}
\format{
  A data frame with 64 observations on the following 5 variables.
  \describe{
    \item{\code{codon}}{a character vector with the three letter of each codon}
    \item{\code{aa}}{a character vector with the three letters identifying the amino acid coded}
    \item{\code{fb}}{a character vector containing the first base of the codon}
    \item{\code{sb}}{a character vector containing the second base of the codon}
    \item{\code{tb}}{a character vector containing the third base of the codon}
  }
}
\source{
\href{https://en.wikipedia.org/wiki/Genetic_code}{Genetic Code (Wikipedia)}
}
\references{
Molecular Biology of the Cell. 4th edition. Alberts B, Johnson A, Lewis J, et al. New York: Garland Science; 2002.
}
\examples{
data(gen.code)
# See the first rows of the data.frame
head(gen.code)
# Table the amino acids by the number of codons
table(gen.code$aa)
# Obviously every one of the four bases appears in the
# same frequency within the first, second and third positions
# within the codons:
table(gen.code$fb) # For the first base within the codon
table(gen.code$sb) # For the second base within the codon
table(gen.code$tb) # For the third base within the codon
# Codons and amino acids in which the first base is "A"
gen.code[gen.code$fb=="A",]
# Table of aa which first codon base is "A"
table(gen.code$aa[gen.code$fb=="A"])
# Codons that code for stop (here shown as an "aa")
gen.code[gen.code$aa=="Stop",]
}
\keyword{datasets}
