\name{gen.code.n.cod}
\alias{gen.code.n.cod}
\docType{data}
\title{
Genetic code for amino acids
}
\description{
This \code{data.frame} gives the number of codons and codons coding for each one of the 21 amino acids (\code{aa}) in the nuclear genetic code. Note that the stop signal is taken as an amino acid
}
\usage{data("gen.code.n.cod")}
\format{
  A data frame with 21 observations on the following 3 variables.
  \describe{
    \item{\code{aa}}{a character vector with the three code letters for the amino acid}
    \item{\code{n.cod}}{a numeric vector with the number of codons coding for the corresponding amino acid (\code{aa})}
    \item{\code{codons}}{a character vector with the codons coding for the amino acid separated by a comma}
  }
}
\details{
Gives the nuclear genetic code
}
\source{
\href{https://en.wikipedia.org/wiki/Genetic_code}{Genetic Code (Wikipedia)}
}
\references{
Molecular Biology of the Cell. 4th edition. Alberts B, Johnson A, Lewis J, et al. New York: Garland Science; 2002.
}
\examples{
data(gen.code.n.cod)
# See the first rows of the data.frame
head(gen.code.n.cod)
# See which amino acids are coded by a single codon
gen.code.n.cod[gen.code.n.cod$n.cod==1,]
# See that all 64 codons are included
sum(gen.code.n.cod$n.cod)
# The degeneracy of the genetic code
summary(gen.code.n.cod$n.cod)
table(gen.code.n.cod$n.cod)
# The three amino acids coded by 6 different codons
gen.code.n.cod[gen.code.n.cod$n.cod==6,]
}
\keyword{datasets}
