\name{prop.bases}
\alias{prop.bases}
\title{
Relative frequencies and informational properties per bases
}
\description{
For a given species, the function returns a \code{data.frame} with the relative frequencies of the four bases as well as informational properties. 
This is done for the first, second and third base of each codon as well as for the total of bases in the genome
}
\usage{
prop.bases(nc = 16, print.data = FALSE, by.row = FALSE)
}
\arguments{
  \item{nc}{
  	Number of column of the matrix \code{codon.freq} (currently values of this parameter could be numbers 1 to 35, which determine the species to be analyzed)
}
  \item{print.data}{
Logic. If \code{TRUE} the function prints information about the species selected to be analyzed
}
  \item{by.row}{
Logic. If \code{TRUE} the output is given as a \code{data.frame} with one row (useful to compare different species)
}
}
\value{
A \code{data.frame} with 4 rows and 8 columns. The first 3 rows are named \code{F, S, T} and correspond to the First, Second and Third codon positions, while the fourth row, named \code{Total}, gives values for the total of the three bases in all codons. On the other hand, the first four columns, named \code{A, T, G, C}, denote the 4 DNA bases, while the last four columns, named \code{Hest, ENB, Info, V.est} give the informational properties obtained from the corresponding row. If \code{by.row = TRUE} the same estimates of informational properties are given formated in a single row, but frequencies of bases are excluded. 
}
\references{
Martinez O. (In preparation). Sampling informational properties of codon use through the tree of life.
}
\author{
Octavio Martinez
}
\seealso{
\code{\link{codon.freq}}, \code{\link{desc.codon.freq}}, \code{\link{codons2bases}}, \code{\link{prop.codons}}, \code{\link{codon.bias}}
}
\examples{
# Let's estimate the proportion of bases for humans
temp <- prop.bases(nc = 16, print.data = TRUE)
# See the result rounded to 4 decimals 
round(temp, 4)
# Note that relative frequencies of the four bases add to 1:
apply(temp[,1:4], 1, sum)
# Also note that the last row (Total) equals the average of
# the three first rows (F, S and T)
round(apply(temp[,1:4], 2, mean), 4)
# Now columns 5 to 8 give the estimated informational properties:
# For example, taking the frequencies in the first base of codons
temp[1, 1:4]
# Gives
round(est.H(temp[1, 1:4])[2:5], 4)
# which is identical to 
round(temp[1, 5:8], 4)
# Now with parameter by.row=TRUE the same output is obtained,
# except that now we have all variables in a single row:
prop.bases(nc = 16, by.row=TRUE)
# Compare with 
temp[,5:8]
# Remove temp
rm(temp)
}
