\name{prop.codons}
\alias{prop.codons}
\title{
Estimates informational properties at codon level
}
\description{
For one of the species present in the \code{codon.freq} \code{data.frame}, this function calculates the observed frequencies of codons (\code{ObsFreq}) as well as the frequencies expected by taking into account the frequencies of the 4 DNA bases (\code{ExpBase}) or the frequencies of the 4 bases at each one of the three codon positions (\code{ExpBinC}). Using that estimates the function determine the main informational properties at codon level
}
\usage{
prop.codons(nc = 16)
}
\arguments{
  \item{nc}{
Number of column of the matrix \code{codon.freq} (currently values of this parameter could be numbers 1 to 35, which determine the species to be analyzed)
}
}
\value{
A \code{list} with two components
  \item{H.est }{A \code{matrix} with 3 rows named \code{ObsFreq},\code{ExpBase} and \code{ExpBinC} and 4 columns with informational properties (\code{Hest, ENC, Info, V.est}) at codon level}
  \item{frequencies }{A \code{data.frame} with 64 rows (one for each codon) and columns \code{codon} (the codon), \code{aa} (the amino acid coded by \code{codon}), \code{ObsFreq} (the observed frequency of the \code{codon} in the data), \code{ExpBase} (the frequency of the \code{codon} expected from the frequencies of the bases in the genome) and \code{ExpBinC} (the frequency of the \code{codon} expected from the frequencies of the bases in each one of the three codon positions)}
}
\references{
Martinez O. (In preparation). Sampling informational properties of codon use through the tree of life.
}
\author{
Octavio Martinez
}
\seealso{
\code{\link{codon.freq}}, \code{\link{desc.codon.freq}}, \code{\link{codons2bases}}, \code{\link{prop.bases}}, \code{\link{codon.bias}}
}
\examples{
# Let's perform the analyses for humans
temp <- prop.codons(nc=16)
# Note that the comment in this object is the name of data:
comment(temp)
class(temp)
names(temp)
# Let's see the first component of the result (H.est = temp[[1]])
temp[[1]]
# And have a look at the first rows of the second (frequencies = temp[[2]])
head(temp[[2]])
# Note how the first row of temp[[1]] can be obtained:
round(est.H(temp[[2]]$ObsFreq/sum(temp[[2]]$ObsFreq)),5)
# and also the second and third rows of temp[[1]] (exercise)
# Remove temp
rm(temp)
}